@@ -1221,6 +1221,9 @@ class Signal1D(BaseSignal, CommonSignal1D):
             right.metadata.General.title = (
                 self.metadata.General.title +
                 " full-width at %.1f maximum right position" % factor)
+        for signal in (left, width, right):
+            signal.axes_manager.set_signal_dimension(0)
+            signal.set_signal_type("")
         if return_interval is True:
             return [width, left, right]
         else:
