@@ -208,7 +208,8 @@ class FancySlicing(object):
     def _slicer(self, slices, isNavigation=None, out=None):
         array_slices = self._get_array_slices(slices, isNavigation)
         if out is None:
-            _obj = self._deepcopy_with_new_data(self.data[array_slices])
+            _obj = self._deepcopy_with_new_data(self.data[array_slices],
+                                                copy_variance=True)
             _to_remove = []
             for slice_, axis in zip(array_slices, _obj.axes_manager._axes):
                 if (isinstance(slice_, slice) or
