@@ -1,4 +1,5 @@
 import os
+import tempfile
 
 import numpy as np
 import nose.tools as nt
@@ -6,11 +7,8 @@ import traits.api as t
 
 import hyperspy.api as hs
 
-my_path = os.path.dirname(__file__)
-my_path2 = os.path.join(my_path, "tiff_files")
-
-# set to False, if you want to keep the files to check them with ImageJ or DM
-remove_files = True
+MY_PATH = os.path.dirname(__file__)
+MY_PATH2 = os.path.join(MY_PATH, "tiff_files")
 
 
 def test_rgba16():
@@ -24,41 +22,40 @@ def test_rgba16_local_tifffile():
 
 
 def _test_rgba16(import_local_tifffile=False):
-    s = hs.load(os.path.join(my_path2, "test_rgba16.tif"),
+    s = hs.load(os.path.join(MY_PATH2, "test_rgba16.tif"),
                 import_local_tifffile=import_local_tifffile)
-    data = np.load(os.path.join(my_path, "npy_files", "test_rgba16.npy"))
+    data = np.load(os.path.join(MY_PATH, "npy_files", "test_rgba16.npy"))
     nt.assert_true((s.data == data).all())
     nt.assert_equal(s.axes_manager[0].units, t.Undefined)
     nt.assert_equal(s.axes_manager[1].units, t.Undefined)
     nt.assert_equal(s.axes_manager[2].units, t.Undefined)
     nt.assert_almost_equal(s.axes_manager[0].scale, 1.0, places=5)
     nt.assert_almost_equal(s.axes_manager[1].scale, 1.0, places=5)
-    nt.assert_almost_equal(s.axes_manager[2].scale, 1.0, places=5)        
+    nt.assert_almost_equal(s.axes_manager[2].scale, 1.0, places=5)
 
 
 def _compare_signal_shape_data(s0, s1):
     nt.assert_equal(s0.data.shape, s1.data.shape)
     np.testing.assert_equal(s0.data, s1.data)
 
+
 def test_read_unit_um():
     # Load DM file and save it as tif
-    s = hs.load(os.path.join(my_path2, 'test_dm_image_um_unit.dm3'))
+    s = hs.load(os.path.join(MY_PATH2, 'test_dm_image_um_unit.dm3'))
     nt.assert_equal(s.axes_manager[0].units, 'µm')
     nt.assert_equal(s.axes_manager[1].units, 'µm')
     nt.assert_almost_equal(s.axes_manager[0].scale, 0.16867, places=5)
     nt.assert_almost_equal(s.axes_manager[1].scale, 0.16867, places=5)
 
-    fname = os.path.join(my_path, 'tiff_files', 'test_export_um_unit.tif')
-    s.save(fname, overwrite=True, export_scale=True)
-
-    # load tif file
-    s2 = hs.load(fname, import_local_tifffile=True)
-    nt.assert_equal(s.axes_manager[0].units, 'µm')
-    nt.assert_equal(s.axes_manager[1].units, 'µm')
-    nt.assert_almost_equal(s2.axes_manager[0].scale, 0.16867, places=5)
-    nt.assert_almost_equal(s2.axes_manager[1].scale, 0.16867, places=5)
-    if remove_files:
-        os.remove(fname)
+    with tempfile.TemporaryDirectory() as tmpdir:
+        fname = os.path.join(tmpdir, 'tiff_files', 'test_export_um_unit.tif')
+        s.save(fname, overwrite=True, export_scale=True)
+        # load tif file
+        s2 = hs.load(fname, import_local_tifffile=True)
+        nt.assert_equal(s.axes_manager[0].units, 'µm')
+        nt.assert_equal(s.axes_manager[1].units, 'µm')
+        nt.assert_almost_equal(s2.axes_manager[0].scale, 0.16867, places=5)
+        nt.assert_almost_equal(s2.axes_manager[1].scale, 0.16867, places=5)
 
 
 def test_read_unit_from_imagej():
@@ -72,7 +69,7 @@ def test_read_unit_from_imagej_local_tifffile():
 
 
 def _test_read_unit_from_imagej(import_local_tifffile=False):
-    fname = os.path.join(my_path, 'tiff_files',
+    fname = os.path.join(MY_PATH, 'tiff_files',
                          'test_loading_image_saved_with_imageJ.tif')
     s = hs.load(fname, import_local_tifffile=import_local_tifffile)
     nt.assert_equal(s.axes_manager[0].units, 'micron')
@@ -82,7 +79,7 @@ def _test_read_unit_from_imagej(import_local_tifffile=False):
 
 
 def test_read_unit_from_imagej_stack(import_local_tifffile=False):
-    fname = os.path.join(my_path, 'tiff_files',
+    fname = os.path.join(MY_PATH, 'tiff_files',
                          'test_loading_image_saved_with_imageJ_stack.tif')
     s = hs.load(fname, import_local_tifffile=import_local_tifffile)
     nt.assert_equal(s.data.shape, (2, 68, 68))
@@ -95,7 +92,7 @@ def test_read_unit_from_imagej_stack(import_local_tifffile=False):
 
 
 def test_read_unit_from_DM_stack(import_local_tifffile=False):
-    fname = os.path.join(my_path, 'tiff_files',
+    fname = os.path.join(MY_PATH, 'tiff_files',
                          'test_loading_image_saved_with_DM_stack.tif')
     s = hs.load(fname, import_local_tifffile=import_local_tifffile)
     nt.assert_equal(s.data.shape, (2, 68, 68))
@@ -105,32 +102,32 @@ def test_read_unit_from_DM_stack(import_local_tifffile=False):
     nt.assert_almost_equal(s.axes_manager[0].scale, 2.5, places=5)
     nt.assert_almost_equal(s.axes_manager[1].scale, 0.16867, places=5)
     nt.assert_almost_equal(s.axes_manager[2].scale, 1.68674, places=5)
-    fname2 = fname.replace('DM_stack.tif', 'DM_stack2.tif')
-    s.save(fname2, overwrite=True)
-    s2 = hs.load(fname2)
-    _compare_signal_shape_data(s, s2)
-    nt.assert_equal(s2.axes_manager[0].units, s.axes_manager[0].units)
-    nt.assert_equal(s2.axes_manager[1].units, 'micron')
-    nt.assert_equal(s2.axes_manager[2].units, 'micron')
-    nt.assert_almost_equal(s2.axes_manager[0].scale, s.axes_manager[0].scale,
-                           places=5)
-    nt.assert_almost_equal(s2.axes_manager[1].scale, s.axes_manager[1].scale,
-                           places=5)
-    nt.assert_almost_equal(s2.axes_manager[2].scale, s.axes_manager[2].scale,
-                           places=5)
-    nt.assert_almost_equal(s2.axes_manager[0].offset, s.axes_manager[0].offset,
-                           places=5)
-    nt.assert_almost_equal(s2.axes_manager[1].offset, s.axes_manager[1].offset,
-                           places=5)
-    nt.assert_almost_equal(s2.axes_manager[2].offset, s.axes_manager[2].offset,
-                           places=5)
-    if remove_files:
-        os.remove(fname2)    
+    with tempfile.TemporaryDirectory() as tmpdir:
+        fname2 = os.path.join(
+            tmpdir, 'test_loading_image_saved_with_DM_stack2.tif')
+        s.save(fname2, overwrite=True)
+        s2 = hs.load(fname2)
+        _compare_signal_shape_data(s, s2)
+        nt.assert_equal(s2.axes_manager[0].units, s.axes_manager[0].units)
+        nt.assert_equal(s2.axes_manager[1].units, 'micron')
+        nt.assert_equal(s2.axes_manager[2].units, 'micron')
+        nt.assert_almost_equal(
+            s2.axes_manager[0].scale, s.axes_manager[0].scale, places=5)
+        nt.assert_almost_equal(
+            s2.axes_manager[1].scale, s.axes_manager[1].scale, places=5)
+        nt.assert_almost_equal(
+            s2.axes_manager[2].scale, s.axes_manager[2].scale, places=5)
+        nt.assert_almost_equal(
+            s2.axes_manager[0].offset, s.axes_manager[0].offset, places=5)
+        nt.assert_almost_equal(
+            s2.axes_manager[1].offset, s.axes_manager[1].offset, places=5)
+        nt.assert_almost_equal(
+            s2.axes_manager[2].offset, s.axes_manager[2].offset, places=5)
+
 
-    
 def test_read_unit_from_imagej_stack_no_scale(import_local_tifffile=False):
-    fname = os.path.join(my_path, 'tiff_files',
-        'test_loading_image_saved_with_imageJ_stack_no_scale.tif')
+    fname = os.path.join(MY_PATH, 'tiff_files',
+                         'test_loading_image_saved_with_imageJ_stack_no_scale.tif')
     s = hs.load(fname, import_local_tifffile=import_local_tifffile)
     nt.assert_equal(s.data.shape, (2, 68, 68))
     nt.assert_equal(s.axes_manager[0].units, t.Undefined)
@@ -139,61 +136,58 @@ def test_read_unit_from_imagej_stack_no_scale(import_local_tifffile=False):
     nt.assert_almost_equal(s.axes_manager[0].scale, 1.0, places=5)
     nt.assert_almost_equal(s.axes_manager[1].scale, 1.0, places=5)
     nt.assert_almost_equal(s.axes_manager[2].scale, 1.0, places=5)
-        
+
 
 def test_read_unit_from_imagej_no_scale(import_local_tifffile=False):
-    fname = os.path.join(my_path, 'tiff_files',
+    fname = os.path.join(MY_PATH, 'tiff_files',
                          'test_loading_image_saved_with_imageJ_no_scale.tif')
     s = hs.load(fname, import_local_tifffile=import_local_tifffile)
     nt.assert_equal(s.axes_manager[0].units, t.Undefined)
     nt.assert_equal(s.axes_manager[1].units, t.Undefined)
     nt.assert_almost_equal(s.axes_manager[0].scale, 1.0, places=5)
     nt.assert_almost_equal(s.axes_manager[1].scale, 1.0, places=5)
-    
+
 
 def test_write_read_unit_imagej(import_local_tifffile=True):
-    fname = os.path.join(my_path, 'tiff_files',
+    fname = os.path.join(MY_PATH, 'tiff_files',
                          'test_loading_image_saved_with_imageJ.tif')
     s = hs.load(fname, import_local_tifffile=import_local_tifffile)
     s.axes_manager[0].units = 'µm'
     s.axes_manager[1].units = 'µm'
-    fname2 = fname.replace('.tif', '2.tif')
-    s.save(fname2, export_scale=True, overwrite=True)
-    s2 = hs.load(fname2, import_local_tifffile=import_local_tifffile)
-    nt.assert_equal(s2.axes_manager[0].units, 'micron')
-    nt.assert_equal(s2.axes_manager[1].units, 'micron')
-    nt.assert_equal(s.data.shape, s.data.shape)
-    if remove_files:
-        os.remove(fname2)
+    with tempfile.TemporaryDirectory() as tmpdir:
+        fname2 = os.path.join(
+            tmpdir, 'test_loading_image_saved_with_imageJ2.tif')
+        s.save(fname2, export_scale=True, overwrite=True)
+        s2 = hs.load(fname2, import_local_tifffile=import_local_tifffile)
+        nt.assert_equal(s2.axes_manager[0].units, 'micron')
+        nt.assert_equal(s2.axes_manager[1].units, 'micron')
+        nt.assert_equal(s.data.shape, s.data.shape)
 
 
 def test_write_read_unit_imagej_with_description(import_local_tifffile=True):
-    fname = os.path.join(my_path, 'tiff_files',
+    fname = os.path.join(MY_PATH, 'tiff_files',
                          'test_loading_image_saved_with_imageJ.tif')
     s = hs.load(fname, import_local_tifffile=import_local_tifffile)
     s.axes_manager[0].units = 'µm'
     s.axes_manager[1].units = 'µm'
     nt.assert_almost_equal(s.axes_manager[0].scale, 0.16867, places=5)
     nt.assert_almost_equal(s.axes_manager[1].scale, 0.16867, places=5)
-    fname2 = fname.replace('.tif', '_description.tif')
-    s.save(fname2, export_scale=False, overwrite=True, description='test')
-    s2 = hs.load(fname2, import_local_tifffile=import_local_tifffile)
-    nt.assert_equal(s2.axes_manager[0].units, t.Undefined)
-    nt.assert_equal(s2.axes_manager[1].units, t.Undefined)
-    nt.assert_almost_equal(s2.axes_manager[0].scale, 1.0, places=5)
-    nt.assert_almost_equal(s2.axes_manager[1].scale, 1.0, places=5)
+    with tempfile.TemporaryDirectory() as tmpdir:
+        fname2 = os.path.join(tmpdir, 'description.tif')
+        s.save(fname2, export_scale=False, overwrite=True, description='test')
+        s2 = hs.load(fname2, import_local_tifffile=import_local_tifffile)
+        nt.assert_equal(s2.axes_manager[0].units, t.Undefined)
+        nt.assert_equal(s2.axes_manager[1].units, t.Undefined)
+        nt.assert_almost_equal(s2.axes_manager[0].scale, 1.0, places=5)
+        nt.assert_almost_equal(s2.axes_manager[1].scale, 1.0, places=5)
 
-    fname3 = fname.replace('.tif', '_description2.tif')
-    s.save(fname3, export_scale=True, overwrite=True, description='test')
-    s3 = hs.load(fname3, import_local_tifffile=import_local_tifffile)
-    nt.assert_equal(s3.axes_manager[0].units, 'micron')
-    nt.assert_equal(s3.axes_manager[1].units, 'micron')
-    nt.assert_almost_equal(s3.axes_manager[0].scale, 0.16867, places=5)
-    nt.assert_almost_equal(s3.axes_manager[1].scale, 0.16867, places=5)
-
-    if remove_files:
-        os.remove(fname2)
-        os.remove(fname3)
+        fname3 = os.path.join(tmpdir, 'description2.tif')
+        s.save(fname3, export_scale=True, overwrite=True, description='test')
+        s3 = hs.load(fname3, import_local_tifffile=import_local_tifffile)
+        nt.assert_equal(s3.axes_manager[0].units, 'micron')
+        nt.assert_equal(s3.axes_manager[1].units, 'micron')
+        nt.assert_almost_equal(s3.axes_manager[0].scale, 0.16867, places=5)
+        nt.assert_almost_equal(s3.axes_manager[1].scale, 0.16867, places=5)
 
 
 def test_saving_with_custom_tag():
@@ -203,14 +197,13 @@ def test_saving_with_custom_tag():
             dtype=np.uint8).reshape(
             (10,
              15)))
-    fname = os.path.join(my_path, 'tiff_files',
-                         'test_saving_with_custom_tag.tif')
-    extratag = [(65000, 's', 1, "Random metadata", False)]
-    s.save(fname, extratags=extratag, overwrite=True)
-    s2 = hs.load(fname)
-    nt.assert_equal(s2.original_metadata['Number_65000'], b"Random metadata")
-    if remove_files:
-        os.remove(fname)
+    with tempfile.TemporaryDirectory() as tmpdir:
+        fname = os.path.join(tmpdir, 'test_saving_with_custom_tag.tif')
+        extratag = [(65000, 's', 1, "Random metadata", False)]
+        s.save(fname, extratags=extratag, overwrite=True)
+        s2 = hs.load(fname)
+        nt.assert_equal(s2.original_metadata[
+                        'Number_65000'], b"Random metadata")
 
 
 def test_read_unit_from_dm():
@@ -224,7 +217,7 @@ def test_read_unit_from_dm_local_tifffile():
 
 
 def _test_read_unit_from_dm(import_local_tifffile=False):
-    fname = os.path.join(my_path2, 'test_loading_image_saved_with_DM.tif')
+    fname = os.path.join(MY_PATH2, 'test_loading_image_saved_with_DM.tif')
     s = hs.load(fname, import_local_tifffile=import_local_tifffile)
     nt.assert_equal(s.axes_manager[0].units, 'µm')
     nt.assert_equal(s.axes_manager[1].units, 'µm')
@@ -232,24 +225,23 @@ def _test_read_unit_from_dm(import_local_tifffile=False):
     nt.assert_almost_equal(s.axes_manager[1].scale, 0.16867, places=5)
     nt.assert_almost_equal(s.axes_manager[0].offset, 139.66264, places=5)
     nt.assert_almost_equal(s.axes_manager[1].offset, 128.19276, places=5)
-    fname2 = fname.replace('DM.tif', 'DM2.tif')
-    s.save(fname2, overwrite=True)
-    s2 = hs.load(fname2)
-    _compare_signal_shape_data(s, s2)
-    nt.assert_equal(s2.axes_manager[0].units, 'micron')
-    nt.assert_equal(s2.axes_manager[1].units, 'micron')
-    nt.assert_almost_equal(s2.axes_manager[0].scale, s.axes_manager[0].scale,
-                           places=5)
-    nt.assert_almost_equal(s2.axes_manager[1].scale, s.axes_manager[1].scale,
-                           places=5)
-    nt.assert_almost_equal(s2.axes_manager[0].offset, s.axes_manager[0].offset,
-                           places=5)
-    nt.assert_almost_equal(s2.axes_manager[1].offset, s.axes_manager[1].offset,
-                           places=5)
-    if remove_files:
-        os.remove(fname2)    
+    with tempfile.TemporaryDirectory() as tmpdir:
+        fname2 = os.path.join(tmpdir, "DM2.tif")
+        s.save(fname2, overwrite=True)
+        s2 = hs.load(fname2)
+        _compare_signal_shape_data(s, s2)
+        nt.assert_equal(s2.axes_manager[0].units, 'micron')
+        nt.assert_equal(s2.axes_manager[1].units, 'micron')
+        nt.assert_almost_equal(s2.axes_manager[0].scale, s.axes_manager[0].scale,
+                               places=5)
+        nt.assert_almost_equal(s2.axes_manager[1].scale, s.axes_manager[1].scale,
+                               places=5)
+        nt.assert_almost_equal(s2.axes_manager[0].offset, s.axes_manager[0].offset,
+                               places=5)
+        nt.assert_almost_equal(s2.axes_manager[1].offset, s.axes_manager[1].offset,
+                               places=5)
+
 
-    
 def test_write_scale_unit():
     _test_write_scale_unit(export_scale=True)
 
@@ -273,11 +265,10 @@ def _test_write_scale_unit(export_scale=True):
     s.axes_manager['y'].scale = 0.25
     s.axes_manager['x'].units = 'nm'
     s.axes_manager['y'].units = 'nm'
-    fname = os.path.join(my_path, 'tiff_files',
-                         'test_export_scale_unit_%s.tif' % export_scale)
-    s.save(fname, overwrite=True, export_scale=export_scale)
-    if remove_files:
-        os.remove(fname)
+    with tempfile.TemporaryDirectory() as tmpdir:
+        fname = os.path.join(
+            tmpdir, 'test_export_scale_unit_%s.tif' % export_scale)
+        s.save(fname, overwrite=True, export_scale=export_scale)
 
 
 def test_write_scale_unit_not_square_pixel():
@@ -296,11 +287,10 @@ def test_write_scale_unit_not_square_pixel():
     s.axes_manager['y'].scale = 0.5
     s.axes_manager['x'].units = 'nm'
     s.axes_manager['y'].units = 'µm'
-    fname = os.path.join(my_path, 'tiff_files',
-                         'test_export_scale_unit_not_square_pixel.tif')
-    s.save(fname, overwrite=True, export_scale=True)
-    if remove_files:
-        os.remove(fname)
+    with tempfile.TemporaryDirectory() as tmpdir:
+        fname = os.path.join(
+            tmpdir, 'test_export_scale_unit_not_square_pixel.tif')
+        s.save(fname, overwrite=True, export_scale=True)
 
 
 def test_write_scale_with_undefined_unit():
@@ -316,11 +306,10 @@ def test_write_scale_with_undefined_unit():
     s.axes_manager[1].name = 'y'
     s.axes_manager['x'].scale = 0.25
     s.axes_manager['y'].scale = 0.25
-    fname = os.path.join(my_path, 'tiff_files',
-                         'test_export_scale_undefined_unit.tif')
-    s.save(fname, overwrite=True, export_scale=True)
-    if remove_files:
-        os.remove(fname)
+    with tempfile.TemporaryDirectory() as tmpdir:
+        fname = os.path.join(
+            tmpdir, 'test_export_scale_undefined_unit.tif')
+        s.save(fname, overwrite=True, export_scale=True)
 
 
 def test_write_scale_with_undefined_scale():
@@ -332,26 +321,24 @@ def test_write_scale_with_undefined_scale():
             dtype=np.uint8).reshape(
             (10,
              15)))
-    fname = os.path.join(my_path, 'tiff_files',
-                         'test_export_scale_undefined_scale.tif')
-    s.save(fname, overwrite=True, export_scale=True)
-    s1 = hs.load(fname)
-    _compare_signal_shape_data(s, s1)
-    if remove_files:
-        os.remove(fname)
+    with tempfile.TemporaryDirectory() as tmpdir:
+        fname = os.path.join(
+            tmpdir, 'test_export_scale_undefined_scale.tif')
+        s.save(fname, overwrite=True, export_scale=True)
+        s1 = hs.load(fname)
+        _compare_signal_shape_data(s, s1)
 
 
 def test_write_scale_with_um_unit():
     """ Lazy test, still need to open the files in ImageJ or DM to check if the
         scale and unit are correct """
-    s = hs.load(os.path.join(my_path, 'tiff_files',
+    s = hs.load(os.path.join(MY_PATH, 'tiff_files',
                              'test_dm_image_um_unit.dm3'))
-    fname = os.path.join(my_path, 'tiff_files', 'test_export_um_unit.tif')
-    s.save(fname, overwrite=True, export_scale=True)
-    s1 = hs.load(fname)
-    _compare_signal_shape_data(s, s1)
-    if remove_files:
-        os.remove(fname)
+    with tempfile.TemporaryDirectory() as tmpdir:
+        fname = os.path.join(tmpdir, 'test_export_um_unit.tif')
+        s.save(fname, overwrite=True, export_scale=True)
+        s1 = hs.load(fname)
+        _compare_signal_shape_data(s, s1)
 
 
 def test_write_scale_unit_image_stack():
@@ -370,34 +357,34 @@ def test_write_scale_unit_image_stack():
     s.axes_manager[0].units = 'nm'
     s.axes_manager[1].units = 'um'
     s.axes_manager[2].units = 'mm'
-    fname = os.path.join(my_path, 'tiff_files',
-                         'test_export_scale_unit_stack2.tif')
-    s.save(fname, overwrite=True, export_scale=True)
-    s1 = hs.load(fname)
-    _compare_signal_shape_data(s, s1)
-    nt.assert_equal(s1.axes_manager[0].units, 'nm')
-    nt.assert_equal(s1.axes_manager[1].units, 'mm') # only one unit can be read
-    nt.assert_equal(s1.axes_manager[2].units, 'mm')
-    nt.assert_almost_equal(s1.axes_manager[0].scale, s.axes_manager[0].scale)
-    nt.assert_almost_equal(s1.axes_manager[1].scale, s.axes_manager[1].scale)
-    nt.assert_almost_equal(s1.axes_manager[2].scale, s.axes_manager[2].scale)
-    if remove_files:
-        os.remove(fname)
+    with tempfile.TemporaryDirectory() as tmpdir:
+        fname = os.path.join(tmpdir, 'test_export_scale_unit_stack2.tif')
+        s.save(fname, overwrite=True, export_scale=True)
+        s1 = hs.load(fname)
+        _compare_signal_shape_data(s, s1)
+        nt.assert_equal(s1.axes_manager[0].units, 'nm')
+        # only one unit can be read
+        nt.assert_equal(s1.axes_manager[1].units, 'mm')
+        nt.assert_equal(s1.axes_manager[2].units, 'mm')
+        nt.assert_almost_equal(
+            s1.axes_manager[0].scale, s.axes_manager[0].scale)
+        nt.assert_almost_equal(
+            s1.axes_manager[1].scale, s.axes_manager[1].scale)
+        nt.assert_almost_equal(
+            s1.axes_manager[2].scale, s.axes_manager[2].scale)
+
 
-        
 def test_saving_loading_stack_no_scale():
-    fname = os.path.join(my_path, 'tiff_files',
-                         'test_export_scale_unit_stack2.tif')
-    s0 = hs.signals.Signal2D(np.zeros((10, 20, 30)))
-    s0.save(fname, overwrite=True)
-    s1 = hs.load(fname)
-    _compare_signal_shape_data(s0, s1)
-    if remove_files:
-        os.remove(fname)
-        
+    with tempfile.TemporaryDirectory() as tmpdir:
+        fname = os.path.join(tmpdir, 'test_export_scale_unit_stack2.tif')
+        s0 = hs.signals.Signal2D(np.zeros((10, 20, 30)))
+        s0.save(fname, overwrite=True)
+        s1 = hs.load(fname)
+        _compare_signal_shape_data(s0, s1)
+
 
 def test_read_FEI_SEM_scale_metadata_8bits():
-    fname = os.path.join(my_path2, 'FEI-Helios-Ebeam-8bits.tif')
+    fname = os.path.join(MY_PATH2, 'FEI-Helios-Ebeam-8bits.tif')
     s = hs.load(fname)
     nt.assert_equal(s.axes_manager[0].units, 'm')
     nt.assert_equal(s.axes_manager[1].units, 'm')
@@ -407,7 +394,7 @@ def test_read_FEI_SEM_scale_metadata_8bits():
 
 
 def test_read_FEI_SEM_scale_metadata_16bits():
-    fname = os.path.join(my_path2, 'FEI-Helios-Ebeam-16bits.tif')
+    fname = os.path.join(MY_PATH2, 'FEI-Helios-Ebeam-16bits.tif')
     s = hs.load(fname)
     nt.assert_equal(s.axes_manager[0].units, 'm')
     nt.assert_equal(s.axes_manager[1].units, 'm')
@@ -417,7 +404,7 @@ def test_read_FEI_SEM_scale_metadata_16bits():
 
 
 def test_read_Zeiss_SEM_scale_metadata_1k_image():
-    fname = os.path.join(my_path2, 'test_tiff_Zeiss_SEM_1k.tif')
+    fname = os.path.join(MY_PATH2, 'test_tiff_Zeiss_SEM_1k.tif')
     s = hs.load(fname)
     nt.assert_equal(s.axes_manager[0].units, 'm')
     nt.assert_equal(s.axes_manager[1].units, 'm')
@@ -427,7 +414,7 @@ def test_read_Zeiss_SEM_scale_metadata_1k_image():
 
 
 def test_read_Zeiss_SEM_scale_metadata_512_image():
-    fname = os.path.join(my_path2, 'test_tiff_Zeiss_SEM_512.tif')
+    fname = os.path.join(MY_PATH2, 'test_tiff_Zeiss_SEM_512.tif')
     s = hs.load(fname)
     nt.assert_equal(s.axes_manager[0].units, 'm')
     nt.assert_equal(s.axes_manager[1].units, 'm')
@@ -437,7 +424,7 @@ def test_read_Zeiss_SEM_scale_metadata_512_image():
 
 
 def test_read_RGB_Zeiss_optical_scale_metadata():
-    fname = os.path.join(my_path2, 'optical_Zeiss_AxioVision_RGB.tif')
+    fname = os.path.join(MY_PATH2, 'optical_Zeiss_AxioVision_RGB.tif')
     s = hs.load(fname, import_local_tifffile=True)
     dtype = np.dtype([('R', 'u1'), ('G', 'u1'), ('B', 'u1')])
     nt.assert_equal(s.data.dtype, dtype)
@@ -449,7 +436,7 @@ def test_read_RGB_Zeiss_optical_scale_metadata():
 
 
 def test_read_BW_Zeiss_optical_scale_metadata():
-    fname = os.path.join(my_path2, 'optical_Zeiss_AxioVision_BW.tif')
+    fname = os.path.join(MY_PATH2, 'optical_Zeiss_AxioVision_BW.tif')
     s = hs.load(fname, force_read_resolution=True, import_local_tifffile=True)
     nt.assert_equal(s.data.dtype, np.uint16)
     nt.assert_equal(s.data.shape, (10, 13))
@@ -460,7 +447,7 @@ def test_read_BW_Zeiss_optical_scale_metadata():
 
 
 def test_read_BW_Zeiss_optical_scale_metadata2():
-    fname = os.path.join(my_path2, 'optical_Zeiss_AxioVision_BW.tif')
+    fname = os.path.join(MY_PATH2, 'optical_Zeiss_AxioVision_BW.tif')
     s = hs.load(fname, force_read_resolution=True)
     nt.assert_equal(s.data.dtype, np.uint16)
     nt.assert_equal(s.data.shape, (10, 13))
@@ -471,7 +458,7 @@ def test_read_BW_Zeiss_optical_scale_metadata2():
 
 
 def test_read_BW_Zeiss_optical_scale_metadata3():
-    fname = os.path.join(my_path2, 'optical_Zeiss_AxioVision_BW.tif')
+    fname = os.path.join(MY_PATH2, 'optical_Zeiss_AxioVision_BW.tif')
     s = hs.load(fname, force_read_resolution=False)
     nt.assert_equal(s.data.dtype, np.uint16)
     nt.assert_equal(s.data.shape, (10, 13))
