@@ -1,6 +1,7 @@
 from distutils.version import StrictVersion
 
 import numpy as np
+import scipy
 import nose.tools as nt
 from unittest import mock
 from nose.plugins.skip import SkipTest
@@ -614,14 +615,14 @@ class TestModelFitBinned:
         g.A.value = 1e3
         self.m = m
 
-    def test_fit_fmin_leastsq(self):
-        self.m.fit(fitter="fmin", method="ls")
+    def test_fit_neldermead_leastsq(self):
+        self.m.fit(fitter="Nelder-Mead", method="ls")
         np.testing.assert_almost_equal(self.m[0].A.value, 9976.14519369)
         np.testing.assert_almost_equal(self.m[0].centre.value, -0.110610743285)
         np.testing.assert_almost_equal(self.m[0].sigma.value, 1.98380705455)
 
-    def test_fit_fmin_ml(self):
-        self.m.fit(fitter="fmin", method="ml")
+    def test_fit_neldermead_ml(self):
+        self.m.fit(fitter="Nelder-Mead", method="ml")
         np.testing.assert_almost_equal(self.m[0].A.value, 10001.39613936,
                                        decimal=3)
         np.testing.assert_almost_equal(self.m[0].centre.value, -0.104151206314,
@@ -664,7 +665,7 @@ class TestModelFitBinned:
         np.testing.assert_almost_equal(self.m[0].centre.value, -0.110610724054)
         np.testing.assert_almost_equal(self.m[0].sigma.value, 1.98380709939)
 
-    def test_fit_bounded(self):
+    def test_fit_bounded_mpfit(self):
         self.m[0].centre.bmin = 0.5
         # self.m[0].bounded = True
         self.m.fit(fitter="mpfit", bounded=True)
@@ -672,7 +673,25 @@ class TestModelFitBinned:
         np.testing.assert_almost_equal(self.m[0].centre.value, 0.5)
         np.testing.assert_almost_equal(self.m[0].sigma.value, 2.08398236966)
 
-    def test_fit_bounded_bad_starting_values(self):
+    def test_fit_bounded_leastsq(self):
+        if StrictVersion(scipy.__version__) < StrictVersion("0.17"):
+            raise SkipTest("least bounds only available in scipy >= 0.17")
+        self.m[0].centre.bmin = 0.5
+        # self.m[0].bounded = True
+        self.m.fit(fitter="leastsq", bounded=True)
+        np.testing.assert_almost_equal(self.m[0].A.value, 9991.65422046, 3)
+        np.testing.assert_almost_equal(self.m[0].centre.value, 0.5)
+        np.testing.assert_almost_equal(self.m[0].sigma.value, 2.08398236966)
+
+    def test_fit_bounded_lbfgs(self):
+        self.m[0].centre.bmin = 0.5
+        # self.m[0].bounded = True
+        self.m.fit(fitter="L-BFGS-B", bounded=True, grad=True)
+        np.testing.assert_almost_equal(self.m[0].A.value, 9991.65422046, 4)
+        np.testing.assert_almost_equal(self.m[0].centre.value, 0.5)
+        np.testing.assert_almost_equal(self.m[0].sigma.value, 2.08398236966)
+
+    def test_fit_bounded_bad_starting_values_mpfit(self):
         self.m[0].centre.bmin = 0.5
         self.m[0].centre.value = -1
         # self.m[0].bounded = True
@@ -681,6 +700,24 @@ class TestModelFitBinned:
         np.testing.assert_almost_equal(self.m[0].centre.value, 0.5)
         np.testing.assert_almost_equal(self.m[0].sigma.value, 2.08398236966)
 
+    def test_fit_bounded_bad_starting_values_leastsq(self):
+        self.m[0].centre.bmin = 0.5
+        self.m[0].centre.value = -1
+        # self.m[0].bounded = True
+        self.m.fit(fitter="leastsq", bounded=True)
+        np.testing.assert_almost_equal(self.m[0].A.value, 9991.65422046, 3)
+        np.testing.assert_almost_equal(self.m[0].centre.value, 0.5)
+        np.testing.assert_almost_equal(self.m[0].sigma.value, 2.08398236966)
+
+    def test_fit_bounded_bad_starting_values_lbfgs(self):
+        self.m[0].centre.bmin = 0.5
+        self.m[0].centre.value = -1
+        # self.m[0].bounded = True
+        self.m.fit(fitter="L-BFGS-B", bounded=True, grad=True)
+        np.testing.assert_almost_equal(self.m[0].A.value, 9991.65422046, 4)
+        np.testing.assert_almost_equal(self.m[0].centre.value, 0.5)
+        np.testing.assert_almost_equal(self.m[0].sigma.value, 2.08398236966)
+
     @nt.raises(ValueError)
     def test_wrong_method(self):
         self.m.fit(method="dummy")
@@ -721,10 +758,10 @@ class TestModelWeighted:
                                     (9.9165596607108739, 1.6628243846485873)):
             np.testing.assert_almost_equal(result, expected, decimal=5)
 
-    def test_fit_fmin_binned(self):
+    def test_fit_neldermead_binned(self):
         self.m.signal.metadata.Signal.binned = True
         self.m.fit(
-            fitter="fmin",
+            fitter="Nelder-Mead",
             method="ls",
         )
         for result, expected in zip(self.m[0].coefficients.value,
@@ -755,10 +792,10 @@ class TestModelWeighted:
                 (0.99165596295068958, 0.16628257462820528)):
             np.testing.assert_almost_equal(result, expected, decimal=5)
 
-    def test_fit_fmin_unbinned(self):
+    def test_fit_neldermead_unbinned(self):
         self.m.signal.metadata.Signal.binned = False
         self.m.fit(
-            fitter="fmin",
+            fitter="Nelder-Mead",
             method="ls",
         )
         for result, expected in zip(
@@ -897,7 +934,7 @@ class TestMultifit:
         nt.assert_is_instance(rs.metadata.Signal.Noise_properties.variance,
                               hs.signals.Signal1D)
 
-    def test_bounded_snapping(self):
+    def test_bounded_snapping_mpfit(self):
         m = self.m
         m[0].A.free = True
         m.signal.data *= 2.
@@ -909,6 +946,18 @@ class TestMultifit:
         np.testing.assert_array_almost_equal(self.m[0].A.map['values'],
                                              [4., 4.])
 
+    def test_bounded_snapping_leastsq(self):
+        m = self.m
+        m[0].A.free = True
+        m.signal.data *= 2.
+        m[0].A.value = 2.
+        m[0].A.bmin = 3.
+        m.multifit(fitter='leastsq', bounded=True, show_progressbar=None)
+        np.testing.assert_array_almost_equal(self.m[0].r.map['values'],
+                                             [3., 3.])
+        np.testing.assert_array_almost_equal(self.m[0].A.map['values'],
+                                             [4., 4.])
+
 
 class TestStoreCurrentValues:
 
